EXPORTS
	??0RSpeechRecognitionCustomCommands@@QAE@AAVRMMFController@@@Z @ 1 NONAME ; public: __thiscall RSpeechRecognitionCustomCommands::RSpeechRecognitionCustomCommands(class RMMFController &)
	??1CSpeechRecognitionCustomCommandParser@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CSpeechRecognitionCustomCommandParser::~CSpeechRecognitionCustomCommandParser(void)
	?AddPronunciation@RSpeechRecognitionCustomCommands@@QAEHKKKAAK@Z @ 3 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::AddPronunciation(unsigned long,unsigned long,unsigned long,unsigned long &)
	?AddRule@RSpeechRecognitionCustomCommands@@QAEHKKKAAK@Z @ 4 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::AddRule(unsigned long,unsigned long,unsigned long,unsigned long &)
	?Cancel@RSpeechRecognitionCustomCommands@@QAEXXZ @ 5 NONAME ; public: void __thiscall RSpeechRecognitionCustomCommands::Cancel(void)
	?CommitChanges@RSpeechRecognitionCustomCommands@@QAEHXZ @ 6 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::CommitChanges(void)
	?CreateGrammar@RSpeechRecognitionCustomCommands@@QAEHAAK@Z @ 7 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::CreateGrammar(unsigned long &)
	?CreateLexicon@RSpeechRecognitionCustomCommands@@QAEHAAK@Z @ 8 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::CreateLexicon(unsigned long &)
	?CreateModelBank@RSpeechRecognitionCustomCommands@@QAEHAAK@Z @ 9 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::CreateModelBank(unsigned long &)
	?E32Dll@@YAHW4TDllReason@@@Z @ 10 NONAME ; int __cdecl E32Dll(enum TDllReason)
	?EndRecSession@RSpeechRecognitionCustomCommands@@QAEHXZ @ 11 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::EndRecSession(void)
	?GetAllClientGrammarIDs@RSpeechRecognitionCustomCommands@@QAEHXZ @ 12 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllClientGrammarIDs(void)
	?GetAllClientLexiconIDs@RSpeechRecognitionCustomCommands@@QAEHXZ @ 13 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllClientLexiconIDs(void)
	?GetAllClientModelBankIDs@RSpeechRecognitionCustomCommands@@QAEHXZ @ 14 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllClientModelBankIDs(void)
	?GetAllGrammarIDs@RSpeechRecognitionCustomCommands@@QAEHXZ @ 15 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllGrammarIDs(void)
	?GetAllLexiconIDs@RSpeechRecognitionCustomCommands@@QAEHXZ @ 16 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllLexiconIDs(void)
	?GetAllModelBankIDs@RSpeechRecognitionCustomCommands@@QAEHXZ @ 17 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllModelBankIDs(void)
	?GetAllModelIDs@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 18 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllModelIDs(unsigned long)
	?GetAllPronunciationIDs@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 19 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllPronunciationIDs(unsigned long)
	?GetAllRuleIDs@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 20 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAllRuleIDs(unsigned long)
	?GetAvailableStorage@RSpeechRecognitionCustomCommands@@QAEHAAH@Z @ 21 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetAvailableStorage(int &)
	?GetEngineProperties@RSpeechRecognitionCustomCommands@@QAEHABV?$RArray@H@@AAV2@@Z @ 22 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetEngineProperties(class RArray<int> const &,class RArray<int> &)
	?GetGrammarIDArrayL@RSpeechRecognitionCustomCommands@@QAEXAAV?$RArray@K@@@Z @ 23 NONAME ; public: void __thiscall RSpeechRecognitionCustomCommands::GetGrammarIDArrayL(class RArray<unsigned long> &)
	?GetLexiconIDArrayL@RSpeechRecognitionCustomCommands@@QAEXAAV?$RArray@K@@@Z @ 24 NONAME ; public: void __thiscall RSpeechRecognitionCustomCommands::GetLexiconIDArrayL(class RArray<unsigned long> &)
	?GetModelBankIDArrayL@RSpeechRecognitionCustomCommands@@QAEXAAV?$RArray@K@@@Z @ 25 NONAME ; public: void __thiscall RSpeechRecognitionCustomCommands::GetModelBankIDArrayL(class RArray<unsigned long> &)
	?GetModelCount@RSpeechRecognitionCustomCommands@@QAEHKAAH@Z @ 26 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetModelCount(unsigned long,int &)
	?GetModelIDArrayL@RSpeechRecognitionCustomCommands@@QAEXAAV?$RArray@K@@@Z @ 27 NONAME ; public: void __thiscall RSpeechRecognitionCustomCommands::GetModelIDArrayL(class RArray<unsigned long> &)
	?GetPronunciationIDArrayL@RSpeechRecognitionCustomCommands@@QAEXAAV?$RArray@K@@@Z @ 28 NONAME ; public: void __thiscall RSpeechRecognitionCustomCommands::GetPronunciationIDArrayL(class RArray<unsigned long> &)
	?GetResultSetL@RSpeechRecognitionCustomCommands@@QAEXAAVCSDClientResultSet@@@Z @ 29 NONAME ; public: void __thiscall RSpeechRecognitionCustomCommands::GetResultSetL(class CSDClientResultSet &)
	?GetRuleIDArrayL@RSpeechRecognitionCustomCommands@@QAEXAAV?$RArray@K@@@Z @ 30 NONAME ; public: void __thiscall RSpeechRecognitionCustomCommands::GetRuleIDArrayL(class RArray<unsigned long> &)
	?GetRuleValidity@RSpeechRecognitionCustomCommands@@QAEHKKAAH@Z @ 31 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetRuleValidity(unsigned long,unsigned long,int &)
	?GetUtteranceDuration@RSpeechRecognitionCustomCommands@@QAEHKKAAVTTimeIntervalMicroSeconds32@@@Z @ 32 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::GetUtteranceDuration(unsigned long,unsigned long,class TTimeIntervalMicroSeconds32 &)
	?LoadEngineParameters@RSpeechRecognitionCustomCommands@@QAEHABV?$RArray@H@@0@Z @ 33 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::LoadEngineParameters(class RArray<int> const &,class RArray<int> const &)
	?LoadGrammar@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 34 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::LoadGrammar(unsigned long)
	?LoadLexicon@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 35 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::LoadLexicon(unsigned long)
	?LoadModels@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 36 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::LoadModels(unsigned long)
	?NewL@CSpeechRecognitionCustomCommandParser@@SAPAV1@AAVMSpeechRecognitionCustomCommandImplementor@@@Z @ 37 NONAME ; public: static class CSpeechRecognitionCustomCommandParser * __cdecl CSpeechRecognitionCustomCommandParser::NewL(class MSpeechRecognitionCustomCommandImplementor &)
	?PlayUtterance@RSpeechRecognitionCustomCommands@@QAEHKK@Z @ 38 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::PlayUtterance(unsigned long,unsigned long)
	?Recognize@RSpeechRecognitionCustomCommands@@QAEHAAVCSDClientResultSet@@@Z @ 39 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::Recognize(class CSDClientResultSet &)
	?Record@RSpeechRecognitionCustomCommands@@QAEHVTTimeIntervalMicroSeconds32@@@Z @ 40 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::Record(class TTimeIntervalMicroSeconds32)
	?RemoveGrammar@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 41 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::RemoveGrammar(unsigned long)
	?RemoveLexicon@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 42 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::RemoveLexicon(unsigned long)
	?RemoveModel@RSpeechRecognitionCustomCommands@@QAEHKK@Z @ 43 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::RemoveModel(unsigned long,unsigned long)
	?RemoveModelBank@RSpeechRecognitionCustomCommands@@QAEHK@Z @ 44 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::RemoveModelBank(unsigned long)
	?RemovePronunciation@RSpeechRecognitionCustomCommands@@QAEHKK@Z @ 45 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::RemovePronunciation(unsigned long,unsigned long)
	?RemoveRule@RSpeechRecognitionCustomCommands@@QAEHKK@Z @ 46 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::RemoveRule(unsigned long,unsigned long)
	?SetClientUid@RSpeechRecognitionCustomCommands@@QAEHVTUid@@@Z @ 47 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::SetClientUid(class TUid)
	?StartRecSession@RSpeechRecognitionCustomCommands@@QAEHW4TRecognitionMode@@@Z @ 48 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::StartRecSession(enum TRecognitionMode)
	?Train@RSpeechRecognitionCustomCommands@@QAEHKAAK@Z @ 49 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::Train(unsigned long,unsigned long &)
	?UnloadRule@RSpeechRecognitionCustomCommands@@QAEHKK@Z @ 50 NONAME ; public: int __thiscall RSpeechRecognitionCustomCommands::UnloadRule(unsigned long,unsigned long)

